summaryrefslogtreecommitdiff
path: root/src/components/connection_handler/include/connection_handler/connection_handler_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/components/connection_handler/include/connection_handler/connection_handler_impl.h')
-rw-r--r--src/components/connection_handler/include/connection_handler/connection_handler_impl.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/components/connection_handler/include/connection_handler/connection_handler_impl.h b/src/components/connection_handler/include/connection_handler/connection_handler_impl.h
index 4c0c7b2985..a4d228f0fe 100644
--- a/src/components/connection_handler/include/connection_handler/connection_handler_impl.h
+++ b/src/components/connection_handler/include/connection_handler/connection_handler_impl.h
@@ -140,9 +140,12 @@ class ConnectionHandlerImpl
/**
* @brief OnDeviceSwitchingStart notifies listeners on device transport
* switching start
* @param device_uid the id of the device which has to be switched.
*/
- void OnDeviceSwitchingStart(const std::string& device_uid) FINAL;
+ void OnDeviceSwitchingStart(const std::string& device_uid_from,
+ const std::string& device_uid_to) FINAL;
/**
* @brief OnDeviceSwitchingFinish notifies listeners on device transport
@@ -140,9 +140,12 @@ class ConnectionHandlerImpl
* @brief OnDeviceSwitchingStart notifies listeners on device transport
* switching start
- * @param device_uid the id of the device which has to be switched.
+ * @param device_uid_from the id of the device which has to switch its
+ * transport
+ * @param device_uid_to the id of the device on new transport
*/